==> style-o-matic-1.1.5.tgz: package/es/components/Grid/GridRow.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, setCorePropDefaults, ROLE } from "../../lib";

var GridRow = (_temp = _class = function (_CoreComponent) {
  _inherits(GridRow, _CoreComponent);

  function GridRow() {
    _classCallCheck(this, GridRow);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  GridRow.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.COLUMN:
              return _this2.renderChild(child, inherited);
            default:
              return child;
          }
        }
        return child;
      })
    );
  };

  return GridRow;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  uirole: ROLE.ROW
}), _temp);


export default GridRow;

==> style-o-matic-1.1.37.tgz: package/es/components/Grid/GridRow.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, getCorePropDefaults, ROLE } from "../../lib";

var GridRow = (_temp = _class = function (_CoreComponent) {
  _inherits(GridRow, _CoreComponent);

  function GridRow() {
    _classCallCheck(this, GridRow);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  GridRow.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    return React.createElement(
      Component,
      props,
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.COLUMN:
              return _this2.renderChild(child, inherited);
            default:
              return child;
          }
        }
        return child;
      })
    );
  };

  return GridRow;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  uirole: ROLE.ROW
}), _temp);


export default GridRow;
